# gee

从github导入仓库到gitee
解决github下载速度慢的问题


## 安装

```bash
pip install git2gitee
```

## 使用

```bash
# git2gitee -u {gitee_username} -t {gitee_api_token} github_repo_url
git2gitee -u mikele -t yourtoken https://github.com/toyourheart163/git2gitee
```
